import requests
import json

def load_input_data(file_path):
    """Load input data from a JSON file."""
    with open(file_path, 'r') as file:
        data = json.load(file)
    return data

def get_bearer_token(client_id, client_secret, cn_maestro_url):
    """Get bearer token using client credentials."""
    url = f"https://{cn_maestro_url}/api/v2/access/token"
    headers = {"Content-Type": "application/x-www-form-urlencoded"}
    data = {"grant_type": "client_credentials", "client_id": client_id, "client_secret": client_secret}
    response = requests.post(url, headers=headers, data=data)
    return response.json()["access_token"]

def create_site(token, cn_maestro_url, network_id, site_data):
    """Create a site with the given details."""
    url = f"https://{cn_maestro_url}/api/v2/cnwave60/networks/{network_id}/sites"
    headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
    response = requests.post(url, headers=headers, json=site_data)
    return response.json()

def create_node(token, cn_maestro_url, node_data):
    """Create a node with the given details."""
    url = f"https://{cn_maestro_url}/api/v2/cnwave60/devices"
    headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
    response = requests.post(url, headers=headers, json=node_data)
    return response.json()

def create_link(token, cn_maestro_url, network_id, link_data):
    """Create a link with the given details."""
    url = f"https://{cn_maestro_url}/api/v2/cnwave60/networks/{network_id}/links"
    headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
    response = requests.post(url, headers=headers, json=link_data)
    return response.json()

# Load input data
input_data = load_input_data("input_data.json")

# Extract API URL, Client ID, and Secret from the input data
cn_maestro_url = input_data["cn_maestro_url"]
client_id = input_data["client_id"]
client_secret = input_data["client_secret"]
network_id = input_data["network_id"]

# Get the bearer token
token = get_bearer_token(client_id, client_secret, cn_maestro_url)

# Create sites
for site in input_data["sites"]:
    create_site_result = create_site(token, cn_maestro_url, network_id, site)
    print("Site creation result:", create_site_result)


# Create nodes
for node in input_data["nodes"]:
    create_node_result = create_node(token, cn_maestro_url, node)
    print("Node creation result:", create_node_result)

# Create links
for link in input_data["links"]:
    create_link_result = create_link(token, cn_maestro_url, network_id, link)
    print("Link creation result:", create_link_result)

